package DefHash;

our $DATE = '2019-06-18'; # DATE
our $VERSION = '1.0.12'; # VERSION

1;
# ABSTRACT: Define things according to a specification, using hashes

__END__

=pod

=encoding UTF-8

=head1 NAME

DefHash - Define things according to a specification, using hashes

=head1 VERSION

This document describes version 1.0.12 of DefHash (from Perl distribution DefHash), released on 2019-06-18.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/DefHash>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-DefHash>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=DefHash>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2015, 2014, 2013, 2012 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
